@@ -61,10 +61,6 @@ pub struct RenderCmdOpts {
     /// Pass additional options to the underlying 'helm template' call, e.g. '--set-string image.tag=${revision}'
     #[structopt(short, long, multiple = true)]
     additional_options: Option<Vec<String>>,
-
-    /// Print rendered manifests to stdout
-    #[structopt(short, long)]
-    stdout: bool,
 }
 
 fn main() -> anyhow::Result<()> {
